==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/sw.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Faili lilipakiwa",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Faili lililopakiwa linazidi kiwango cha juu cha ukubwa wa faili linalielekea katika php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Faili iliyopakiliwa imezidi kiwango cha ukubwa wa faili iliyoelekezwa maalum katika fomu ya HTML",
    "The file was only partially uploaded" : "Faili lilipakiwa kwa sehemu ndogo tu",
    "No file was uploaded" : "Hakuna faili lililopakiwa",
    "Missing a temporary folder" : "Imekosa faili la muda",
    "Could not write file to disk" : "Haikuweza kuandika faili kwenye disk",
    "A PHP extension stopped the file upload" : "Uongezaji wa PHP umesimamisha upakiaji wa faili",
    "No file uploaded or file size exceeds maximum of %s" : "Hakuna faili lililopakiwa au faili lilizidi kiwango cha juu cha %s",
    "New text file" : "New text file",
    "File not found" : "Faili halipatikani",
    "Text" : "Maandishi",
    "Nextcloud Assistant" : "Msaidizi wa Nextcloud",
    "Translate" : "Tafsiri",
    "Delete task" : "Futa jukumu",
    "Reload" : "Reload",
    "Enter your name" : "Ingiza jina lako",
    "Guest" : "Mgeni",
    "submit" : "wasilisha",
    "you" : "wewe",
    "Copy link" : "Nakili kiungio",
    "Remove link" : "Ondoa kiungio",
    "guest" : "mgeni",
    "Offline" : "Nje ya mtandao",
    "Saving …" : "Inahifadhi...",
    "Saved" : "Imehifadhiwa",
    "Unsaved changes" : "Mabadiliko yasiyohifadhiwa",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Enter" : "Ingiza",
    "Shift" : "Hamisha",
    "Link" : "Kiungio",
    "Smart picker" : "Smart picker",
    "Action" : "Vitendo",
    "Undo" : "Tendua",
    "Redo" : "Redo",
    "Open link" : "Fungua kiungio",
    "Edit link" : "Hariri kiungo",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "Url",
    "Formatting help" : "Uasidizi wa uambizaji",
    "Translation failed" : "Utafsiri umeshindikana",
    "Translate from" : "Translate from",
    "Select language" : "Chagua lugha",
    "to" : "kwa",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Upload" : "Pakia",
    "Edit" : "Hariri",
    "Copy code block" : "Copy code block",
    "Source code" : "Msimbo wa chanzo",
    "Both" : "Both",
    "Hide outline" : "Hide outline",
    "Show outline" : "Show outline",
    "Done" : "Imefanyika",
    "Lists" : "Lists",
    "Table" : "Jedwali",
    "Details" : "Maelezo ya kina",
    "Ctrl" : "Dhibiti",
    "Option" : "Chaguo",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
    "Choose" : "Chagua",
    "Choose {file}" : "Chagua {file}",
    "Add folder description" : "Add folder description",
    "Cannot copy, please copy the link manually" : "Haiwezi kunakili, tafadhali nakili kiungio kwa njia za kawaida",
    "Copy link to clipboard" : "Copy link to clipboard"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/sw.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Faili lilipakiwa",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Faili lililopakiwa linazidi kiwango cha juu cha ukubwa wa faili linalielekea katika php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Faili iliyopakiliwa imezidi kiwango cha ukubwa wa faili iliyoelekezwa maalum katika fomu ya HTML",
    "The file was only partially uploaded" : "Faili lilipakiwa kwa sehemu ndogo tu",
    "No file was uploaded" : "Hakuna faili lililopakiwa",
    "Missing a temporary folder" : "Imekosa faili la muda",
    "Could not write file to disk" : "Haikuweza kuandika faili kwenye disk",
    "A PHP extension stopped the file upload" : "Uongezaji wa PHP umesimamisha upakiaji wa faili",
    "No file uploaded or file size exceeds maximum of %s" : "Hakuna faili lililopakiwa au faili lilizidi kiwango cha juu cha %s",
    "New text file" : "New text file",
    "File not found" : "Faili halipatikani",
    "Text" : "Maandishi",
    "Reload" : "Reload",
    "Enter your name" : "Ingiza jina lako",
    "Guest" : "Mgeni",
    "submit" : "wasilisha",
    "you" : "wewe",
    "Copy link" : "Nakili kiungio",
    "Remove link" : "Ondoa kiungio",
    "guest" : "mgeni",
    "Offline" : "Nje ya mtandao",
    "Saving …" : "Inahifadhi...",
    "Saved" : "Imehifadhiwa",
    "Unsaved changes" : "Mabadiliko yasiyohifadhiwa",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Enter" : "Ingiza",
    "Shift" : "Hamisha",
    "Bold" : "Bold",
    "Bold text" : "Bold text",
    "Italic" : "Italic",
    "Strikethrough" : "Strikethrough",
    "Underline" : "Underline",
    "Underlined text" : "Underlined text",
    "Heading 1" : "Heading 1",
    "Blockquote" : "Blockquote",
    "Code block" : "Code block",
    "Link" : "Kiungio",
    "Insert emoji" : "Insert emoji",
    "Smart picker" : "Smart picker",
    "Action" : "Vitendo",
    "Undo" : "Tendua",
    "Redo" : "Redo",
    "Open link" : "Fungua kiungio",
    "Edit link" : "Hariri kiungo",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "Url",
    "Save" : "Hifadhi",
    "Formatting help" : "Uasidizi wa uambizaji",
    "Translate" : "Tafsiri",
    "Nextcloud Assistant" : "Msaidizi wa Nextcloud",
    "Delete task" : "Futa jukumu",
    "Translation failed" : "Utafsiri umeshindikana",
    "Translate from" : "Translate from",
    "Select language" : "Chagua lugha",
    "to" : "kwa",
    "Translate to" : "Translate to",
    "Replace" : "Replace",
    "Edit" : "Hariri",
    "Upload" : "Pakia",
    "Copy code block" : "Copy code block",
    "Source code" : "Msimbo wa chanzo",
    "Both" : "Both",
    "Hide outline" : "Hide outline",
    "Show outline" : "Show outline",
    "Done" : "Imefanyika",
    "Heading 2" : "Heading 2",
    "Heading 3" : "Heading 3",
    "Lists" : "Lists",
    "Table" : "Jedwali",
    "Details" : "Maelezo ya kina",
    "Ctrl" : "Dhibiti",
    "Option" : "Chaguo",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
    "Choose" : "Chagua",
    "Choose {file}" : "Chagua {file}",
    "Add folder description" : "Add folder description",
    "Copied to the clipboard" : "Copied to the clipboard",
    "Cannot copy, please copy the link manually" : "Haiwezi kunakili, tafadhali nakili kiungio kwa njia za kawaida",
    "Copy link to clipboard" : "Copy link to clipboard"
},
"nplurals=2; plural=(n != 1);");
